@@ -1,7 +1,7 @@
 .onAttach <- function(libname, pkgname) {
   if (interactive() &&
       check_default_data_path(MESSAGE_FUN = packageStartupMessage) &&
-      check_for_newer_data(mustWork = FALSE))
+      check_for_newer_data())
   {
     packageStartupMessage("The data in the default path `",
                           normalizePath(get_default_data_path()),
